@@ -86,8 +86,7 @@ class AddTorrentsCmdbase(metaclass=CommandMeta):
                                       base=objects.cfg['srv.path.complete'],
                                       directories_only=True)
         if option == '--labels':
-            curlbl = args.curarg.split(',')[-1]
-            return candidates.labels(curlbl)
+            return candidates.labels()
 
 
 class TorrentDetailsCmdbase(mixin.get_single_torrent, metaclass=CommandMeta):
@@ -621,4 +620,4 @@ class LabelCmd(metaclass=CommandMeta):
     def completion_candidates_posargs(cls, args):
         """Complete positional arguments"""
         curlbl = args.curarg.split(',')[-1]
-        return candidates.labels(curlbl)
+        return candidates.labels()
